from .accounting import AccountingResource
from .activity_notes import ActivityNotesResource
from .assets import AssetsResource
from .branches import BranchesResource
from .companies import CompaniesResource
from .contacts import ContactsResource
from .customer_categories import CustomerCategoriesResource
from .customers import CustomersResource
from .custom_field_groups import CustomFieldGroupsResource
from .custom_fields import CustomFieldsResource
from .employees import EmployeesResource
from .estimates import EstimatesResource
from .inventory import InventoryResource
from .invoices import InvoicesResource
from .job_categories import JobCategoriesResource
from .job_templates import JobTemplatesResource
from .leads import LeadsResource
from .locations import LocationsResource
from .marketing_campaigns import MarketingCampaignsResource
from .marketing_categories import MarketingCategoriesResource
from .payment_methods import PaymentMethodsResource
from .payments import PaymentsResource
from .reports import ReportsResource
from .sales_representatives import SalesRepresentativesResource
from .statistics import StatisticsResource
from .tasks import TasksResource
from .taxes import TaxesResource
from .teams import TeamsResource
from .terms import TermsResource
from .users import UsersResource
from .work_orders import WorkOrdersResource

__all__ = [
    "AccountingResource",
    "ActivityNotesResource",
    "AssetsResource",
    "BranchesResource",
    "CompaniesResource",
    "ContactsResource",
    "CustomerCategoriesResource",
    "CustomersResource",
    "CustomFieldGroupsResource",
    "CustomFieldsResource",
    "EmployeesResource",
    "EstimatesResource",
    "InventoryResource",
    "InvoicesResource",
    "JobCategoriesResource",
    "JobTemplatesResource",
    "LeadsResource",
    "LocationsResource",
    "MarketingCampaignsResource",
    "MarketingCategoriesResource",
    "PaymentMethodsResource",
    "PaymentsResource",
    "ReportsResource",
    "SalesRepresentativesResource",
    "StatisticsResource",
    "TasksResource",
    "TaxesResource",
    "TeamsResource",
    "TermsResource",
    "UsersResource",
    "WorkOrdersResource",
]
